"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEnhancedReducer = exports.getActionType = exports.useKeyActionTypes = exports.useKeyInitialState = void 0;

var _react = require("react");

var useKeyInitialState = {
  keyCode: null,
  keyName: null,
  isEscape: false,
  isEnter: false,
  isSpace: false,
  isRightArrow: false,
  isLeftArrow: false,
  isUpArrow: false,
  isDownArrow: false,
  isTab: false,
  isWithShift: false,
  isWithCtrl: false,
  isNumber: false,
  isCaps: false,
  isSmall: false,
  isSpecialCharacter: false
};
exports.useKeyInitialState = useKeyInitialState;
var useKeyActionTypes = {
  ENTER_KEY: 'ENTER_KEY',
  ESCAPE_KEY: 'ESCAPE_KEY',
  RESET_CAPTURES: 'RESET_CAPTURES',
  CAPS_ALPHABET: 'CAPS',
  SMALL_ALPHABET: 'SMALL',
  NUMBER: 'NUMBER'
};
exports.useKeyActionTypes = useKeyActionTypes;
var keyCodeMapper = {
  13: useKeyActionTypes.ENTER_KEY,
  27: useKeyActionTypes.ESCAPE_KEY
};

var isCapitalLetterPressed = function isCapitalLetterPressed(key) {
  return /^[A-Z]$/.test(key);
};

var isSmallLetterPressed = function isSmallLetterPressed(key) {
  return /^[a-z]$/.test(key);
};

var getActionType = function getActionType(eventDetails) {
  if (!eventDetails) {
    throw new Error('Event called with no details');
  }

  if (keyCodeMapper[eventDetails.keyCode]) return keyCodeMapper[eventDetails.keyCode];

  if (isCapitalLetterPressed(eventDetails.key)) {
    return useKeyActionTypes.CAPS_ALPHABET;
  }

  if (isSmallLetterPressed(eventDetails.key)) {
    return useKeyActionTypes.SMALL_ALPHABET;
  }

  if (eventDetails.keyCode >= 48 && eventDetails.keyCode <= 57) {
    return useKeyActionTypes.NUMBER;
  }

  return 'SOME_OTHER_KEY';
};

exports.getActionType = getActionType;

var useEnhancedReducer = function useEnhancedReducer(reducer) {
  return (0, _react.useCallback)(function (state, action) {
    return reducer(state, action);
  }, [reducer]);
};

exports.useEnhancedReducer = useEnhancedReducer;